@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "DummyTest.h"
 #include <QAbstractItemModelTester>
@@ -30,7 +16,7 @@
 #include <resources/ResourcesUpdatesModel.h>
 #include <Transaction/TransactionModel.h>
 
-#include <qtest.h>
+#include <QTest>
 #include <QtTest>
 #include <QAction>
 
@@ -78,10 +64,10 @@ private Q_SLOTS:
         rum->prepare();
         QSignalSpy spySetup(m_appBackend->backendUpdater(), &AbstractBackendUpdater::progressingChanged);
         QVERIFY(!m_appBackend->backendUpdater()->isProgressing() || spySetup.wait());
-        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt()*2/3);
+        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt());
         QCOMPARE(m->hasUpdates(), true);
 
-        QCOMPARE(m->index(0,0).data(UpdateModel::ChangelogRole).toString(), {});
+        QCOMPARE(m->index(0,0).data(UpdateModel::ChangelogRole).toString(), QString{});
 
         QSignalSpy spy(m, &QAbstractItemModel::dataChanged);
         m->fetchUpdateDetails(0);
@@ -102,7 +88,7 @@ private Q_SLOTS:
         rum->prepare();
         QSignalSpy spySetup(m_appBackend->backendUpdater(), &AbstractBackendUpdater::progressingChanged);
         QVERIFY(!m_appBackend->backendUpdater()->isProgressing() || spySetup.wait());
-        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt()*2/3);
+        QCOMPARE(m_appBackend->updatesCount(), m_appBackend->property("startElements").toInt());
         QCOMPARE(m->hasUpdates(), true);
 
         for(int i=0, c=m->rowCount(); i<c; ++i) {
