@@ -13,7 +13,6 @@
 #include <QString>
 #include <QDir>
 #include <QDebug>
-#include <QThread>
 #include <QTimer>
 #include <QAction>
 #include <QMimeDatabase>
@@ -25,8 +24,6 @@
 #include <QNetworkRequest>
 #include <QCryptographicHash>
 #include <QMap>
-#include <QEventLoop>
-#include <QThreadPool>
 
 extern "C" {
 #include <fwupd.h>
@@ -63,6 +60,8 @@ public:
     void handleError(GError *perror);
 
     static QString cacheFile(const QString &kind, const QString &baseName);
+    void setDevices(GPtrArray*);
+    void setRemotes(GPtrArray*);
 
 Q_SIGNALS:
     void initialized();
@@ -71,15 +70,13 @@ private:
     ResultsStream* resourceForFile(const QUrl & );
     void refreshRemotes();
     void addUpdates();
-    void addResourceToList(FwupdResource *res);
+    void addResource(FwupdResource *res);
     QSet<AbstractResource*> getAllUpdates();
 
     static QMap<GChecksumType,QCryptographicHash::Algorithm> gchecksumToQChryptographicHash();
     static void refreshRemote(FwupdBackend* backend, FwupdRemote *remote, quint64 cacheAge, GCancellable *cancellable);
     static QByteArray getChecksum(const QString &filename, QCryptographicHash::Algorithm hashAlgorithm);
-    static bool downloadFile(const QUrl &uri, const QString &filename);
 
-    FwupdResource * createDevice(FwupdDevice *device);
     FwupdResource * createRelease(FwupdDevice *device);
     FwupdResource * createApp(FwupdDevice *device);
 
@@ -89,7 +86,6 @@ private:
     int m_startElements;
     QList<AbstractResource*> m_toUpdate;
     GCancellable *m_cancellable;
-    QThreadPool m_threadPool;
 };
 
 #endif // FWUPDBACKEND_H
