@@ -1,23 +1,9 @@
-/***************************************************************************
- *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *   Copyright © 2018 Abhijeet Sharma <sharma.abhijeet2096@gmail.com>      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2018 Abhijeet Sharma <sharma.abhijeet2096@gmail.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "FwupdTransaction.h"
 
@@ -31,7 +17,6 @@ FwupdTransaction::FwupdTransaction(FwupdResource* app, FwupdBackend* backend)
     setCancellable(true);
     setStatus(QueuedStatus);
 
-    Q_ASSERT(!m_app->file().isEmpty());
     Q_ASSERT(!m_app->deviceId().isEmpty());
     QTimer::singleShot(0, this, &FwupdTransaction::install);
 }
@@ -45,7 +30,7 @@ void FwupdTransaction::install()
     if(m_app->isDeviceLocked())
     {
         QString device_id = m_app->deviceId();
-        if(device_id.isNull()) {
+        if(device_id.isEmpty()) {
             qWarning() << "Fwupd Error: No Device ID set, cannot unlock device " << this << m_app->name();
         } else if(!fwupd_client_unlock(m_backend->client, device_id.toUtf8().constData(),nullptr, &error)) {
             m_backend->handleError(error);
@@ -54,13 +39,19 @@ void FwupdTransaction::install()
         return;
     }
 
-    if(!QFileInfo::exists(m_app->file()))
-    {
+    const QString fileName = m_app->cacheFile();
+    if(!QFileInfo::exists(fileName)) {
         const QUrl uri(m_app->updateURI());
         setStatus(DownloadingStatus);
         QNetworkAccessManager *manager = new QNetworkAccessManager(this);
         auto reply = manager->get(QNetworkRequest(uri));
-        QFile* file = new QFile(m_app->file());
+        QFile* file = new QFile(fileName);
+        if (!file->open(QFile::WriteOnly)) {
+            qWarning() << "Fwupd Error: Could not open to write" << fileName << uri;
+            setStatus(DoneWithErrorStatus);
+            file->deleteLater();
+            return;
+        }
 
         connect(reply, &QNetworkReply::finished, this, [this, file, reply](){
             file->close();
@@ -71,7 +62,7 @@ void FwupdTransaction::install()
                 file->remove();
                 setStatus(DoneWithErrorStatus);
             } else {
-                fwupdInstall();
+                fwupdInstall(file->fileName());
             }
         });
         connect(reply, &QNetworkReply::readyRead, this, [file, reply](){
@@ -80,11 +71,11 @@ void FwupdTransaction::install()
     }
     else
     {
-        fwupdInstall();
+        fwupdInstall(fileName);
     }
 }
 
-void FwupdTransaction::fwupdInstall()
+void FwupdTransaction::fwupdInstall(const QString &file)
 {
     FwupdInstallFlags install_flags = FWUPD_INSTALL_FLAG_NONE;
     g_autoptr(GError) error = nullptr;
@@ -93,7 +84,7 @@ void FwupdTransaction::fwupdInstall()
     if(m_app->isOnlyOffline())
         install_flags = static_cast<FwupdInstallFlags>(install_flags | FWUPD_INSTALL_FLAG_OFFLINE);
 
-    if(!fwupd_client_install(m_backend->client, m_app->deviceId().toUtf8().constData(), m_app->file().toUtf8().constData(), install_flags, nullptr, &error))
+    if(!fwupd_client_install(m_backend->client, m_app->deviceId().toUtf8().constData(), file.toUtf8().constData(), install_flags, nullptr, &error))
     {
         m_backend->handleError(error);
         setStatus(DoneWithErrorStatus);
