@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "AppPackageKitResource.h"
 #include <AppStreamQt/screenshot.h>
@@ -26,7 +12,6 @@
 #include <appstream/AppStreamUtils.h>
 #include <PackageKit/Daemon>
 #include <KLocalizedString>
-#include <KToolInvocation>
 #include <QIcon>
 #include <QFile>
 #include <QProcess>
@@ -112,12 +97,12 @@ QStringList AppPackageKitResource::mimetypes() const
     return m_appdata.provided(AppStream::Provided::KindMimetype).items();
 }
 
-static const QVector<AppStream::Component::Kind> s_addonKinds = {AppStream::Component::KindAddon, AppStream::Component::KindCodec};
+static constexpr auto s_addonKinds = {AppStream::Component::KindAddon, AppStream::Component::KindCodec};
 
 QStringList AppPackageKitResource::categories()
 {
     auto cats = m_appdata.categories();
-    if (!s_addonKinds.contains(m_appdata.kind()))
+    if (!kContainsValue(s_addonKinds, m_appdata.kind()))
         cats.append(QStringLiteral("Application"));
     return cats;
 }
@@ -167,7 +152,7 @@ AbstractResource::Type AppPackageKitResource::type() const
 {
     static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
     const auto desktops = m_appdata.compulsoryForDesktops();
-    return s_addonKinds.contains(m_appdata.kind())               ? Addon
+    return kContainsValue(s_addonKinds, m_appdata.kind())        ? Addon
            : (desktops.isEmpty() || !desktops.contains(desktop)) ? Application
                                                                  : Technical;
 }
