@@ -1,26 +1,13 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "AbstractResource.h"
 #include "AbstractResourcesBackend.h"
 #include <ReviewsBackend/AbstractReviewsBackend.h>
+#include <ReviewsBackend/Rating.h>
 #include <Category/CategoryModel.h>
 #include <KLocalizedString>
 #include <KFormat>
@@ -33,6 +20,7 @@ AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     : QObject(parent)
 {
     connect(this, &AbstractResource::stateChanged, this, &AbstractResource::sizeChanged);
+    connect(this, &AbstractResource::stateChanged, this, &AbstractResource::versionsChanged);
     connect(this, &AbstractResource::stateChanged, this, &AbstractResource::reportNewState);
 }
 
@@ -123,6 +111,12 @@ Rating* AbstractResource::rating() const
     return ratings ? ratings->ratingForApplication(const_cast<AbstractResource*>(this)) : nullptr;
 }
 
+QVariant AbstractResource::ratingVariant() const
+{
+    auto instance = rating();
+    return instance ? QVariant::fromValue<Rating>(*instance) : QVariant();
+}
+
 QStringList AbstractResource::extends() const
 {
     return {};
@@ -228,7 +222,7 @@ QString AbstractResource::categoryDisplay() const
         ret.append(cat->name());
     }
     ret.sort();
-    return ret.join(QStringLiteral(", "));
+    return ret.join(QLatin1String(", "));
 }
 
 QUrl AbstractResource::url() const
@@ -246,3 +240,27 @@ QString AbstractResource::executeLabel() const
 {
     return i18n("Launch");
 }
+
+QString AbstractResource::upgradeText() const
+{
+    QString installed = installedVersion(), available = availableVersion();
+    if (installed == available) {
+        // Update of the same version; show when old and new are
+        // the same (common with Flatpak runtimes)
+        return i18n("Update to version %1", available);
+    } else if (!installed.isEmpty() && !available.isEmpty()) {
+        // Old and new version numbers
+        // This thing with \u009C is a fancy feature in QML text handling:
+        // when the string will be elided, it shows the string after
+        // the last \u009C. This allows us to show a smaller string
+        // when there's now enough room
+
+        // All of this is mostly for the benefit of KDE Neon users,
+        // since the version strings there are really really long
+        return i18nc("Do not translate or alter \\u009C", "%1 → %2\u009C%1 → %2\u009C%2", installed, available);
+    } else {
+        // Available version only, for when the installed version
+        // isn't available for some reason
+        return available;
+    }
+}
