@@ -1,25 +1,10 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "AbstractResourcesBackend.h"
-#include "AbstractResource.h"
 #include "Category/Category.h"
 #include <QHash>
 #include <QMetaObject>
@@ -83,6 +68,8 @@ AbstractResourcesBackend::AbstractResourcesBackend(QObject* parent)
             fetchingChangedTimer->start();
         else
             fetchingChangedTimer->stop();
+        
+        Q_EMIT fetchingUpdatesProgressChanged();
     });
 }
 
@@ -113,9 +100,6 @@ bool AbstractResourcesBackend::Filters::shouldFilter(AbstractResource* res) cons
     if(!extends.isEmpty() && !res->extends().contains(extends)) {
         return false;
     }
-    if(!resourceUrl.isEmpty() && res->url() != resourceUrl) {
-        return false;
-    }
 
     if(!origin.isEmpty() && res->origin() != origin) {
         return false;
@@ -146,3 +130,8 @@ QStringList AbstractResourcesBackend::extends() const
 {
     return {};
 }
+
+int AbstractResourcesBackend::fetchingUpdatesProgress() const
+{
+    return isFetching() ? 42 : 100;
+}
