@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright ?? 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef UTILS_H
 #define UTILS_H
@@ -51,6 +37,17 @@ static T kTransform(const Q &input, _UnaryOperation op)
     return ret;
 }
 
+template <typename T, typename Q>
+static T kTransform(const Q &input)
+{
+    T ret;
+    ret.reserve(input.size());
+    for(const auto& v : input) {
+        ret += v;
+    }
+    return ret;
+}
+
 template <typename T, typename Q, typename _UnaryOperation>
 static T kAppend(const Q &input, _UnaryOperation op)
 {
@@ -89,6 +86,10 @@ template <typename Q, typename W>
 static bool kContains(const Q& list, W func)
 { return std::any_of(list.begin(), list.end(), func); }
 
+template <typename Q, typename W>
+static bool kContainsValue(const Q& list, W value)
+{ return std::find(list.begin(), list.end(), value) != list.end(); }
+
 template <typename T>
 static QVector<T> kSetToVector(const QSet<T> & set)
 {
@@ -102,25 +103,13 @@ static QVector<T> kSetToVector(const QSet<T> & set)
 template <typename T>
 static QSet<T> kToSet(const QVector<T> & set)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     return QSet<T>(set.begin(), set.end());
-#else
-    QSet<T> ret;
-    ret.reserve(set.size());
-    for(auto &x: set)
-        ret.insert(x);
-    return ret;
-#endif
 }
 
 template <typename T>
 static QSet<T> kToSet(const QList<T> & set)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     return QSet<T>(set.begin(), set.end());
-#else
-    return set.toSet();
-#endif
 }
 
 class ElapsedDebug : private QElapsedTimer
